#!/bin/sh
# Se recibe como parametro el nombre del jboss a reiniciar
#
# REQUISITOS:
# 1) debe existir un usuario del sistema con ese nombre
# 2) debe existir en /var/proyectos un directorio con el nombre del jboss
# 3) debe existir un script para arrancar el jboss en el directorio con nombre arrancar_$jboss.sh
############################################################


# Declaracion variables
DIR_PROYECTOS="/var/proyectos"

# Comprobaciones iniciales
test "$1" = "" && { echo "Sintaxis: $0 nombre_jboss"; exit 1; }

jboss=$1
script_arranque="arrancar_$jboss.sh"

grep "^$jboss:" /etc/passwd >/dev/null 2>&1 || { echo "ERROR|No existe el usuario $jboss en el sistema"; exit 2; }

test -d $DIR_PROYECTOS/$jboss || { echo "ERROR|No existe el directorio $DIR_PROYECTOS/$jboss"; exit 3; }

test -x $DIR_PROYECTOS/$jboss/$script_arranque || { echo "ERROR|No existe el script de arranque del jboss $script_arranque"; exit 4; }

echo "OK|Comenzando reinicio de JBoss $jboss ..."
echo -n "Matando procesos java... "

# Matamos procesos
pid=`ps -efH | grep $jboss | grep java | grep -v grep | awk '{print $2}' | tail -1`

test "$pid" = "" && { echo "NO PARECE QUE ESTE LEVANTADO EL JBOSS. Compruebalo y reinicialo a mano"; exit 5; }

echo -n "PID - $pid... "

if su - $jboss -c "kill -9 $pid"; then
	sleep 4
	pid=`ps -efH | grep $jboss | grep java | grep -v grep | awk '{print $2}' | tail -1`
	test "$pid" = "" && echo "OK!" || { echo "Siguen existiendo procesos! Comprobar. Saliendo"; exit 101; }
else
	# No se ha podido matar el proceso
	echo "ERROR MATANDO EL PROCESO!!!. Saliendo. Comprobar funcionamiento de jboss."
	exit 100
fi

# JBoss Parado
echo -n "Arrancando jboss..."
su - $jboss -c "cd $DIR_PROYECTOS/$jboss; ./$script_arranque >/dev/null 2>&1" && echo "OK!" || echo "ERROR. Mirar por si acaso."

echo -n "Comprobando procesos... "
sleep 10
if ps -efH | grep $jboss | grep java | grep -v grep >/dev/null 2>&1; then
	echo "OK!"
else
	echo "Parece que no hay procesos. Comprobar."
	exit 102
fi
echo "Fin del proceso"

exit 0

