#!/bin/sh

###########################################################################
# Fichero:      EliminaMensajesViricos.sh
# Fecha:        20040828
# Desc:         Script que busca en las colas de las instancias de correo
#		mensajes que cumplan una serie de patrones predefinidos.
#		Por defecto LISTA los mensajes encontrados, no elimina ni mueve nada.
#		Busca en el directorio messages para cualquier tipo de instancia.
#		Si la instancia es MTA, busca tambien en el dir deferred con destino los buzones
#		Preparado para ejecutarse en las siguientes mquinas:
#			eui3sps (eui8smtp)
#			c211m (eui6smtp)
#			eui1m (eui1m2, eui1m3, eui1m5, eui10smtp)
#			eui2m (eui2m2)
#
# Entrada:      Tiene varias opciones:
#		(sin parametros):	Ejecucion por defecto; busca patrones predefinidos y LISTA mensajes encontrados
#		-p "patron"	:	Busca adems de los patrones por defecto el patrn especificado.
#					Si se quieren especificar ms patrones se separar por pipes "|"
#					LOS PATRONES NO DEBEN CONTENER PIPES "|", YA QUE SE TRATARIAN COMO DIFERENTES.
#		-P "patron"	:	Busca slo el patron especificado. No busca los predefinidos. Igual que -d
#		-m directorio	:	Mueve los mensajes encontrados al directorio especificado
#		-e		:	Elimina los mensajes encontrados.
# 	(def.)	-l		:	Slo lista los mensajes encontrados.
#		-d destino	:	Slo para MTAs. Al tratar el directorio deferred, busca mensajes
#					en el subdirectorio especificado, adems de hacia los buzones.
#		-D destino	:	Slo para MTAs. Al tratar el directorio deferred, slo busca donde digamos.
#
# Salida:       Fichero de log en /export/home/gestion/colas/logs/
#
# Modific:
#			(**pendiente**)		Escribir en fichero de LOG como una opcion (para crontab, etc)
#
###########################################################################


trata_mensajes()
{
	echo "######################################"
	echo "Inicio tratamiento.... $fechatotal ..."
	for instancia_completa in $INSTANCIAS; do
	        instancia=`echo $instancia_completa | cut -d"|" -f1`
	        mta=`echo $instancia_completa | cut -d"|" -f2`
					echo

					#Comprobacion previa de que existen directorios
					test ! -d /cola/$instancia/cola1/messages && { echo "No existe directorio /cola/$instancia/cola1/messages"; echo "Ignorando $instancia"; continue; }

	        # Busqueda de patrones en messages
	        IFS="|"
	        for patron in $PATRONES; do
						echo "Buscando $instancia - messages el patron $patron"
	        	IFS=$IFS_ANT
	        	grep -l "$patron" /cola/$instancia/cola1/messages/* 2>/dev/null | while read linea
	        	do
	        		case "$ACCION" in
	        		  "ELIMINAR")
	        		  	echo "$ACCION|$patron|$linea"
#	        		  	rm $linea
	        		  	;;
	        		  "MOVER")
	        		  	echo "$ACCION|$patron|$linea|$DIR_MOVER"
#	        			mv $linea $DIR_MOVER
	        		  	;;
	        		  "LISTAR")
	        		  	echo "$ACCION|$patron|$linea"
	        		  	;;
  			       	esac
	        	done
						echo
	        done
	        IFS=$IFS_ANT

		if [ "$mta" = "SI" ]; then
  		 # Hacemos hashdir de lo que el usuario haya pedido
		   # y los aniadimos a DIRS_DEFERRED
		   for dir_def_sin_hash in $DIRS_DEFERRED_SIN_HASH
		   do
		      salida_hash=`$HASH/hashdir $dir_def_sin_hash`
		      DIRS_DEFERRED="$DIRS_DEFERRED $salida_hash$dir_def_sin_hash"
		   done

		   # Tratamos directorios deferred que haya en la variable
       for dir_deferred in $DIRS_DEFERRED; do
					echo "Buscando $instancia - deferred hacia $dir_deferred"

					#Comprobacion previa de que existen directorios
					test ! -d /cola/$instancia/cola1/deferred/SMTP-Deliver/$dir_deferred && { echo "No hay correos encolados hacia $dir_deferred (o no existe directorio)"; echo; continue; }

          find /cola/$instancia/cola1/deferred/SMTP-Deliver/$dir_deferred/ -type f ! -name "env*" 2>/dev/null | while read linea
          do
			        IFS="|"
			        for patron in $PATRONES; do
       	         IFS=$IFS_ANT
			           if grep -l "$patron" $linea >/dev/null 2>/dev/null; then
		        		case "$ACCION" in
		        		  "ELIMINAR")
		        		  	echo "$ACCION|$patron|$linea"
#       		  			rm $linea
		        		  	;;
		        		  "MOVER")
  		        		  echo "$ACCION|$patron|$linea|$DIR_MOVER"
#	        					mv $linea $DIR_MOVER
		        		  	;;
		        		  "LISTAR")
		        		  	echo "$ACCION|$patron|$linea"
		        		  	;;
	  			       	esac
			           	break
			           fi
							done #for patron
							IFS=$IFS_ANT
	        done #while fichero
			 echo
			 done #for dir_deferred
	     IFS=$IFS_ANT
		fi  #mta=SI
	done  #for instancia
	echo
	echo "Fin tratamiento"
	echo "###############"
}

######### ENTRADA PROGRAMA PRINCIPAL ###############
# Declaracion de variables GLOBALES
DirEjecucion=`pwd`
HostEjecucion=`hostname`
fecha=`date +%Y%m%d`
hora=`date +%H:%M:%S`
fechaTotal=`date +%Y%m%d%H%M%S`

#FICH_LOG=

IFS_ANT=$IFS

# Valores de ejecucion por defecto
# La variable ACCCION puede tener los valores ELIMINAR, MOVER o LISTAR
# DIRS_DEFERRED tiene los directorios dentro de deferred/SMTP-Deliver/ donde buscara
# PATRONES tiene los patrones a buscar, separados por PIPES (|)
DIRS_DEFERRED="40/b7/eui2m2.euskaltel.es 52/f3/eui1m2.euskaltel.es 44/25/eui1m3.euskaltel.es f4/40/eui3m.euskaltel.es 20/b1/eui5m1.euskaltel.es 12/e2/eui5m2.euskaltel.es 04/14/eui5m3.euskaltel.es"
PATRONES="xxx.lugardesexo.com|manuela_2525@yahoo.es|From: webmaster@sexo4ever.com"
ACCION="LISTAR"
DIR_MOVER=""
DIRS_DEFERRED_SIN_HASH=""

#
# Comprobacion de parametros
#
if test $# -gt 0; then
	while test "$1" != ""; do
		case "$1" in
			"-?")
				echo "Ayuda del comando $0"
				echo "----------------------------------------------------------------------------"
				echo "Descripcion: Comando que busca en las colas de correo mensajes que contienen alguno de los patrones definidos"
				echo "Sintaxis: $0 [-?] [-l|-e|-m directorio] [(-p|-P) \"patron1[|patron2|patron3...]\"] [(-d|-D) \"destino[ destino2 destino3...]\""
				echo "Valores por defecto:"
				echo "Patrones a buscar          : $PATRONES"
				echo "Destinos a buscar (en MTAs): $DIRS_DEFERRED"
				echo "Accion                     : $ACCION"
				echo "Opciones:"
				echo "     -?            :   Muestra la ayuda"
				echo "     -l            :   Lista los archivos encontrados (valor por defecto)"
				echo "     -e            :   Elimina archivos encontrados"
				echo "     -m directorio :   Mueve archivos encontrados a directorio especificado (sin barra al final)"
				echo "     -p patron     :   Busca ademas de los patrones predefinidos el patron o patrones especificados (separar patrones con |)"
				echo "     -P patron     :   Igual que -p pero no busca los patrones predefinidos"
        echo "     -d destino    :   En los MTA busca mensajes encolados para el destino especificado ademas de los destinos predefinidos (separar destinos con espacios)"
        echo "     -D destino    :   Igual que -d pero no busca los destinos predefinidos"
        echo "----------------------------------------------------------------------------"
				exit 0
			;;
		  "-p")
				test "$2" != "" && { PATRONES="$PATRONES|$2"; echo "-p: Aniadiendo patron $2"; } || { echo "-p: Se esperaba un patron"; exit 1; }
				shift
			;;
		  "-P")
		  	test "$2" != "" && { PATRONES="$2"; echo "-p: Buscando solo $2"; } || { echo "-P: Se esperaba un patron"; exit 1; }
		  	shift
		  	;;
		  "-l")
		  	ACCION="LISTAR"
		  	;;
		  "-e")
		  	ACCION="ELIMINAR"
		  	;;
		  "-m")
		  	ACCION="MOVER"
		  	if test "$2" != "" ; then
		  		echo $2 | grep "/$" >/dev/null 2>&1 && { echo "-m: directorio sin barra al final"; exit 1; }
		  		test -d $2 && { DIR_MOVER="$2"; echo "-m: Dejando archivos en $2"; } || { echo "-m: Se esperaba un directorio"; exit 1; }
		  	else
		  		echo "-m: Se esperaba un directorio"
		  		exit 1
		  	fi
		  	shift
		  	;;
		  "-d")
		  	# Si se selecciona -d no mostramos mensaje ya que lo comprobaremos despues con la instancia
			test "$2" != "" && DIRS_DEFERRED_SIN_HASH="$2" || { echo "-d: Se esperaba un patron para deferred"; exit 1; }
			shift
			;;
		  "-D")
		  	# Si se selecciona -D no mostramos mensaje ya que lo comprobaremos despues con la instancia
			test "$2" != "" && { DIRS_DEFERRED_SIN_HASH="$2"; DIRS_DEFERRED=""; } || { echo "-D: Se esperaba un patron para deferred"; exit 1; }
			shift
			;;
		esac
		shift

	done
fi

# Comprobamos host en el que se ejecuta para terminar de declarar las variables
# INSTANCIA tendra las instancias que habra que tratar y si son mta o no
# HASH tendra el directorio con el binario hashdir para poder mirar en deferred.
# HASH solo esta declarado en maquinas con MTAs

HASH=""
case "$HostEjecucion" in
        "eui1m")
        	HASH="/correo/eui10smtp/bin/msg/admin/bin"
                INSTANCIAS="eui1m2|NO eui1m3|NO eui1m5|NO eui10smtp|SI"
                ;;

        "eui2m")
                INSTANCIAS="eui2m2|NO"
                ;;
	"eui5m")
		INSTANCIAS"eui5m1|NO eui5m2|NO eui5m3|NO"
		;;
        "c211m")
                INSTANCIAS="eui6smtp|SI"
                HASH="/opt/server4/correo6/bin/msg/admin/bin"
                ;;
        "eui3sps")
                INSTANCIAS="eui8smtp|SI"
                HASH="/opt/server4/bin/msg/admin/bin"
                ;;
        *)
                echo "Script no preparado para ejecutarse en esta maquina!!"
                exit 1
                ;;
esac

# Comprobacion de HASH

# Si el usuario ha utilizado -d o -D...
if test "$DIRS_DEFERRED_SIN_HASH" != ""; then
	# si HASH esta vacio es que no hay MTA, luego no se mira en deferred
	test "$HASH" = "" && { echo "No se puede usar -d o -D en maquina sin MTA"; exit 1; }

	# Mostrmos mensaje por pantalla de -d o -D
	test "$DIRS_DEFERRED" = "" && echo "-D: Buscando solo para $DIRS_DEFERRED_SIN_HASH" || echo "-d: Aniadiendo busqueda para $DIRS_DEFERRED_SIN_HASH"


	# Si no existe el ejecutable hashdir se ignora -d o -D
	test ! -x $HASH/hashdir && { echo "hashdir no encontrado. Se ignora -d o -D"; DIRS_DEFERRED_SIN_HASH=""; }

fi

#Llamamos a la funcion principal
trata_mensajes
