#!/bin/sh
#####################################################################
# Nombre:       RecojeAccesoListas.sh
# Autor:        Eduardo Gonzalez
# Descripcion:  Analiza log smtp para ver ultima recepcion de correo
#               de una serie de mails (corresponde con listas de distribucion)
# Entradas:     Fichero de salida con el formato: FECHA|mail
#               Fichero de LOG_SMTP a analizar
# Restricc:     - Debe existir el fichero /export/home/gestion/cuentas/listasDistribucion.txt
#                 con la lista de mails a buscar en el log
#               - Si el fichero de salida existe se aniaden los datos eliminando registros repetidos
#####################################################################

#
# COMPROBACIONES VARIAS
#
FICH_LISTAS=/export/home/gestion/cuentas/listasDistribucion.txt

test ! -f $FICH_LISTAS $$ echo "No existe listado de emails a analizar!! Este fichero debe llamarse: $FICH_LISTAS" && exit 2

test "$1" = "" && echo "Sintaxis: $0 fichero(s)_salida fichero(s)_log_smtp" && exit 1
test "$2" = "" && echo "Sintaxis: $0 fichero(s)_salida fichero(s)_log_smtp" && exit 1
test ! -f $2 && echo "pasa un fichero de log de smtp como parametro2" && exit 1

# si existe el fichero de salida pero el formato no es adecuado salimos
if test -f $1; then
        if head -1 $1 | grep "|"; then
                :
        else
                echo "FORMATO DE FICHERO DE SALIDA INADECUADO. REVISA LLAMADA A SCRIPT"
                exit 3
        fi
else
        # si no existe el fichero de salida lo creamos
        echo "Fichero de salida no existe. Creando uno nuevo..." && touch $1
fi

#
# DECLARACION DE VARIABLES
#

FICH_SALIDA=$1
# de momento no se usa fichero temporal
#FICH_TMP=/export/home/gestion/cuentas/fileTmp.$$

#
# ENTRADA PROGRAMA PRINCIPAL
#
while [ "$2" != "" ]; do
 LOG_SMTP=$2

 # por si algun fichero que se manda como parametro no existe pasamos a la siguiente iteracion
 if test ! -f $LOG_SMTP; then
        shift
        continue
 fi

 echo "Procesando fichero $LOG_SMTP"
 echo

 TipoArchivo=`file $LOG_SMTP | awk '{print $2}'`

 cat $FICH_LISTAS | while read MAIL; do

 # Si el fichero es gzip se trata diferente
 if [ "$TipoArchivo" = "gzip" ]; then
        #Comprobacion de que haya mails para el destino
        if gzip -cd $LOG_SMTP |fgrep "SMTP-Accept" | grep -l "$MAIL[^:]*$" > /dev/null 2>&1; then
          # Si hay hacemos el tratamiento... (no usamos variable total en awk)
          gzip -cd $LOG_SMTP | fgrep "SMTP-Accept" | grep "$MAIL[^:]*$" | sed "s/^\[\(.*\)\/\(.*\)\/\(....\).*$/\3|\2|\1/g" |
          awk -F"|" '{
               if ( $2 == "Jan" )
                       mes="01"
               else if ( $2 == "Feb" )
                       mes="02"
               else if ( $2 == "Mar" )
                       mes="03"
               else if ( $2 == "Apr" )
                       mes="04"
               else if ( $2 == "May" )
                       mes="05"
               else if ( $2 == "Jun" )
                       mes="06"
               else if ( $2 == "Jul" )
                       mes="07"
               else if ( $2 == "Aug" )
                       mes="08"
               else if ( $2 == "Sep" )
                       mes="09"
               else if ( $2 == "Oct" )
                       mes="10"
               else if ( $2 == "Nov" )
                       mes="11"
               else if ( $2 == "Dic" )
                       mes="12"
               print $1 mes $3 "|DIRECCION"
          '} | sed "s/DIRECCION/$MAIL/" | tail -1 >> $FICH_SALIDA
        else
          # Si no hay escribimos lo siguiente
          echo "00000000|$MAIL" >> $FICH_SALIDA
        fi
 else # Tipo NO GZIP
        #Comprobacion de que haya mails para el destino
        if fgrep "SMTP-Accept" $LOG_SMTP | grep -l "$MAIL[^:]*$" > /dev/null 2>&1; then
          # Si hay hacemos el tratamiento... (no usamos variable total en awk)
          fgrep "SMTP-Accept" $LOG_SMTP | grep "$MAIL[^:]*$" | sed "s/^\[\(.*\)\/\(.*\)\/\(....\).*$/\3|\2|\1/g" |
          awk -F"|" '{
               if ( $2 == "Jan" )
                       mes="01"
               else if ( $2 == "Feb" )
                       mes="02"
               else if ( $2 == "Mar" )
                       mes="03"
               else if ( $2 == "Apr" )
                       mes="04"
               else if ( $2 == "May" )
                       mes="05"
               else if ( $2 == "Jun" )
                       mes="06"
               else if ( $2 == "Jul" )
                       mes="07"
               else if ( $2 == "Aug" )
                       mes="08"
               else if ( $2 == "Sep" )
                       mes="09"
               else if ( $2 == "Oct" )
                       mes="10"
               else if ( $2 == "Nov" )
                       mes="11"
               else if ( $2 == "Dic" )
                       mes="12"
               print $1 mes $3 "|DIRECCION"
          '} | sed "s/DIRECCION/$MAIL/" | tail -1 >> $FICH_SALIDA
        else
          # Si no hay escribimos lo siguiente
          echo "00000000|$MAIL" >> $FICH_SALIDA
        fi
 fi
 done # while listaDistribucion

 # Rotamos los parametros por si quedan archivos
 shift
done # while parametro2

#
# Una vez terminado el proceso ordenamos el fichero de salida y quitamos repetidos para tener solo ultimas fechas
# Con estos 3 comandos hacemos que tanto si los datos aniadidos son anteriores o posteriores de igual.
#
sort -t"|" -k 2,2 -k 1,1 -f -r -o $FICH_SALIDA $FICH_SALIDA
sort -m -t"|" -k 2,2 -u -o $FICH_SALIDA $FICH_SALIDA
sort -t"|" -k 2,2 -f -o $FICH_SALIDA $FICH_SALIDA

echo "#################### Fin del proceso ######################"